@@ -353,7 +353,7 @@ class Fid(Base):
         """
         if self.ranges is not None:
             return numpy.array([[peak for peak in self.peaks if peak > min(peak_range) and peak < max(peak_range)]
-                    for peak_range in self.ranges])
+                    for peak_range in self.ranges], dtype=object)
         else:
             return []
     @property
@@ -363,7 +363,7 @@ class Fid(Base):
         """
         if self._index_ranges is not None:
             return numpy.array([[peak for peak in self._index_peaks if peak > min(peak_range) and peak < max(peak_range)]
-                    for peak_range in self._index_ranges])
+                    for peak_range in self._index_ranges], dtype=object)
         else:
             return []
 
@@ -1335,10 +1335,11 @@ class FidArray(Base):
             if isinstance(getattr(self, fid_id), Fid):
                 fids = [f.id for f in self.get_fids()]
                 idx = fids.index(fid_id)
-                at = list(self._params['acqtime'])
-                at.pop(idx)
-                self._params['acqtime'] = at
                 delattr(self, fid_id)
+                if hasattr(self, '_params') and self._params is not None:
+                    at = list(self._params['acqtime'])
+                    at.pop(idx)
+                    self._params['acqtime'] = at
             else:
                 raise AttributeError('{} is not an FID object.'.format(fid_id))
         else:
@@ -1724,13 +1725,9 @@ Ctrl+Alt+Right - assign
         objects owned by this :class:`~nmrpy.data_objects.FidArray`. See
         also :meth:`~nmrpy.data_objects.Fid.calibrate`.
         
-        :keyword fid_number: list or number, index of
-        :class:`~nmrpy.data_objects.Fid` to use for calibration. 
-        If None, the whole data array is plotted.
+        :keyword fid_number: list or number, index of :class:`~nmrpy.data_objects.Fid` to use for calibration. If None, the whole data array is plotted.
 
-        :keyword assign_only_to_index: if True, assigns calibration only
-        to :class:`~nmrpy.data_objects.Fid` objects indexed by fid_number;
-        if False, assigns to all.
+        :keyword assign_only_to_index: if True, assigns calibration only to :class:`~nmrpy.data_objects.Fid` objects indexed by fid_number; if False, assigns to all.
 
         :keyword voff: vertical offset for spectra
         """
@@ -1755,13 +1752,9 @@ Left - select peak
         objects owned by this :class:`~nmrpy.data_objects.FidArray`. See
         :meth:`~nmrpy.data_objects.Fid.peakpicker`.
 
-        :keyword fid_number: list or number, index of
-        :class:`~nmrpy.data_objects.Fid` to use for peak-picking. 
-        If None, data array is plotted.
+        :keyword fid_number: list or number, index of :class:`~nmrpy.data_objects.Fid` to use for peak-picking. If None, data array is plotted.
 
-        :keyword assign_only_to_index: if True, assigns selections only
-        to :class:`~nmrpy.data_objects.Fid` objects indexed by fid_number,
-        if False, assigns to all
+        :keyword assign_only_to_index: if True, assigns selections only to :class:`~nmrpy.data_objects.Fid` objects indexed by fid_number, if False, assigns to all.
 
         :keyword voff: vertical offset for spectra
         """
