@@ -1,6 +1,5 @@
 import unittest
 from nmrpy.data_objects import *
-from nmrpy import __version__
 import numpy
 import os
 
@@ -90,8 +89,18 @@ class TestFidInitialisation(unittest.TestCase):
         fid = fid_array.get_fids()[0]
         fid.peaks = [ 4.71,  4.64,  4.17,  0.57]
         fid.ranges = [[ 5.29,  3.67], [1.05,  0.27]]
-        self.assertTrue(numpy.allclose(fid._grouped_peaklist.shape, numpy.array([[ 4.71,  4.64,  4.17], [ 0.57]]).shape))
-        self.assertTrue(numpy.allclose(fid._grouped_index_peaklist.shape, numpy.array([[6551, 6569, 6691], [7624]]).shape))
+        self.assertTrue(
+            numpy.allclose(
+                fid._grouped_peaklist.shape,
+                numpy.array([[4.71, 4.64, 4.17], [0.57]], dtype=object).shape,
+            )
+        )
+        self.assertTrue(
+            numpy.allclose(
+                fid._grouped_index_peaklist.shape,
+                numpy.array([[6551, 6569, 6691], [7624]], dtype=object).shape,
+            )
+        )
 
 
     def test_failed_fid_ranges_setter(self):
@@ -245,7 +254,7 @@ class TestFidArrayInitialisation(unittest.TestCase):
         fid_array = FidArray()
         self.assertTrue(fid_array.id is None)
         fid_array = FidArray(id='string')
-        self.assertTrue(fid_array.id is 'string')
+        self.assertTrue(fid_array.id == 'string')
         print(fid_array)
 
     def test_failed_fid_array_assignment(self):
@@ -701,6 +710,7 @@ class NMRPyTest:
         'fidutils'      - Fid utilities tests
         'fidarrayutils' - FidArray utilities tests
         'plotutils'     - plotting utilities tests
+        'noplot'        - all tests except plotting utilities (scripted usage)
         """
         runner = unittest.TextTestRunner()
         baseinit_test = unittest.makeSuite(TestBaseInitialisation)
@@ -717,6 +727,11 @@ class NMRPyTest:
             suite.addTests(fidutils_test)
             suite.addTests(fidarrayutils_test)
             suite.addTests(plotutils_test)
+        elif tests == 'noplot':
+            suite.addTests(fidinit_test)
+            suite.addTests(fidarrayinit_test)
+            suite.addTests(fidutils_test)
+            suite.addTests(fidarrayutils_test)
         elif tests == 'fidinit':
             suite.addTests(fidinit_test)
         elif tests == 'fidarrayinit':
